@@ -723,8 +723,6 @@ src_braille_setting_new ()
 static void
 src_braille_load_values (SRCBraille *braille)
 {
-    gint default_int_val;
-    
     sru_assert (braille);
     
     if (!braille->device)
@@ -844,6 +842,7 @@ src_braille_terminate ()
 static SRCBraille* 
 src_braille_get_global_settings ()
 {
+    sru_assert (src_braille);
     return src_braille;
 }
 
@@ -853,7 +852,7 @@ src_braille_set_device (gchar *device)
     SRCBraille *braille;
     
     braille = src_braille_get_global_settings ();
-    
+    sru_assert (braille);
     sru_assert (device && braille && braille->device);
     
     if (strcmp (device, braille->device) != 0)
@@ -872,6 +871,7 @@ src_braille_set_port_no (gint port)
     SRCBraille *braille;
     
     braille = src_braille_get_global_settings ();
+    sru_assert (braille);
     
     if (braille->port != port)
     {
@@ -888,7 +888,7 @@ src_braille_set_style (gchar *style)
     SRCBraille *braille;
     
     braille = src_braille_get_global_settings ();
-    
+    sru_assert (braille);
     sru_assert (style && braille->style);
     
     if (strcmp (style, braille->style) != 0)
@@ -907,7 +907,7 @@ src_braille_set_cursor_style (gchar *cursor_style)
     SRCBraille *braille;
     
     braille = src_braille_get_global_settings ();
-    
+    sru_assert (braille);
     sru_assert (cursor_style && braille->cursor_style);
     
     if (strcmp (cursor_style, braille->cursor_style) != 0)
@@ -926,6 +926,7 @@ src_braille_set_translation_table (gchar *translation_table)
     SRCBraille *braille;
     
     braille = src_braille_get_global_settings ();
+    sru_assert (braille);
     
     sru_assert (translation_table && braille->translation_table);
     if (strcmp (translation_table, braille->translation_table) != 0)
@@ -955,11 +956,14 @@ src_braille_set_position_sensor (gint position_sensor)
     SRCBraille *braille;
     
     braille = src_braille_get_global_settings ();
+    sru_assert (braille);
     
     if (position_sensor != braille->position_sensor)
     {
 	braille->position_sensor = position_sensor;
     }
+
+    return TRUE;
 }
 
 gboolean
@@ -968,11 +972,14 @@ src_braille_set_optical_sensor (gint optical_sensor)
     SRCBraille *braille;
     
     braille = src_braille_get_global_settings ();
+    sru_assert (braille);
     
     if (optical_sensor != braille->optical_sensor)
     {
 	braille->optical_sensor = optical_sensor;
     }
+
+    return TRUE;
 }
 
 gboolean
@@ -981,11 +988,14 @@ src_braille_set_offset (gint offset)
     SRCBraille *braille;
     
     braille = src_braille_get_global_settings ();
+    sru_assert (braille);
     
     if (offset != braille->offset)
     {
 	braille->offset = offset;
     }
+
+    return TRUE;
 }
 
 gint
@@ -994,6 +1004,7 @@ src_braille_get_offset ()
     SRCBraille *braille;
     
     braille = src_braille_get_global_settings ();
+    sru_assert (braille);
     
     return braille->offset;
 }
@@ -1004,6 +1015,7 @@ src_braille_get_optical_sensor ()
     SRCBraille *braille;
     
     braille = src_braille_get_global_settings ();
+    sru_assert (braille);
     
     return braille->optical_sensor;
 }
@@ -1014,6 +1026,7 @@ src_braille_get_position_sensor ()
     SRCBraille *braille;
     
     braille = src_braille_get_global_settings ();
+    sru_assert (braille);
     
     return braille->position_sensor;
 }
@@ -1024,6 +1037,7 @@ src_braille_get_port_no ()
     SRCBraille *braille;
     
     braille = src_braille_get_global_settings ();
+    sru_assert (braille);
     
     return braille->port;
 }
@@ -1034,6 +1048,7 @@ src_braille_get_translation_table ()
     SRCBraille *braille;
     
     braille = src_braille_get_global_settings ();
+    sru_assert (braille && braille->translation_table);
     
     return braille->translation_table;
 }
@@ -1044,6 +1059,7 @@ src_braille_get_cursor_style ()
     SRCBraille *braille;
     
     braille = src_braille_get_global_settings ();
+    sru_assert (braille && braille->cursor_style);
     
     return braille->cursor_style;
 }
@@ -1054,6 +1070,7 @@ src_braille_get_style ()
     SRCBraille *braille;
     
     braille = src_braille_get_global_settings ();
+    sru_assert (braille && braille->style);
     
     return braille->style;
 }
@@ -1062,8 +1079,9 @@ gchar*
 src_braille_get_device ()
 {
     SRCBraille *braille;
-    
+        
     braille = src_braille_get_global_settings ();
+    sru_assert (braille && braille->device);
     
     return braille->device;
 }
