@@ -1725,6 +1725,9 @@ src_process_key (SREvent *event,
 {
     SRHotkeyData *srhotkey_data;
 
+    if (!src_use_speech)
+	return;
+	
     if (!sre_get_event_data (event, (void**)&srhotkey_data))
 	return;
     if (!srhotkey_data)
@@ -2429,6 +2432,7 @@ main (gint argc,
     gboolean    horiz_split     = FALSE;
     gboolean 	login_enabled	= FALSE;    
 
+    
     struct poptOption poptopt[] = 
     {		
 	{
@@ -2613,7 +2617,8 @@ main (gint argc,
 		    LIBGNOMEUI_PARAM_CRASH_DIALOG, FALSE,
 		    NULL);
     sru_log_init ();
-	
+    
+    login_time = FALSE;	
     src_use_braille = (disable_braille ? FALSE :
 			(enable_braille ? TRUE : -1));
 
@@ -2641,7 +2646,7 @@ main (gint argc,
     
     if (login_enabled)
     {
-	/*To be continued*/
+	login_time = TRUE;
     }
 
     src_init (mouse_tracking, focus_tracking, config_source, invert,
