@@ -1248,7 +1248,7 @@ srle_change_type (SRLEvent *event)
 	    !srle_is_for_watched_acc (event) &&
 	    srle_is_for_focused_ancestor_acc (event))
 	    event->type = SRL_EVENT_FOCUS2;
-	if (last_link_index != new_link_index)
+	if (last_link_index != new_link_index && new_link_index != -1)
 	    event->type = SRL_EVENT_FOCUS;
 	last_link_index = new_link_index;
     }
@@ -1414,7 +1414,8 @@ srl_text_event_is_reported (SRLEvent *event,
     else
 	rv = TRUE;
 
-    if (srle_acc_has_role (event, SPI_ROLE_SPIN_BUTTON))
+    if (srle_acc_has_role (event, SPI_ROLE_SPIN_BUTTON) ||
+        srle_acc_has_role (event, SPI_ROLE_SLIDER))
         rv = !srl_info_is_value_changed (info, info2);
 
     /* when a text-changed event for child of combos is emitted,
@@ -1546,7 +1547,7 @@ srl_event_is_reported (SRLEvent *event)
 	    rv = TRUE;
 	else if (srle_has_type (event, SRL_EVENT_VALUE_CHANGED))
 	    rv = srle_acc_has_role (event, SPI_ROLE_SPIN_BUTTON) ||
-		    srle_acc_has_role (event, SPI_ROLE_SLIDER);
+		 srle_acc_has_role (event, SPI_ROLE_SLIDER);
 	else if (srle_has_type (event, SRL_EVENT_VISIBLE_DATA_CHANGED))
 	    rv = TRUE;
     }
